==> charcoal-0.6.0.zip: charcoal-0.6.0/web_app/02_breadcrumb/classes/tasks/BreadcrumbTask.class.php <==
<?php
/**
* ѥꥹȥ
*
* PHP version 5
*
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/
class BreadcrumbTask extends Object implements ITask
{
	/*
	 *    󥹥ȥ饯
	 */
	public function __construct()
	{
		parent::__construct();
	}

	/**
	 * ̾
	 */
	public function getTaskName()
	{
		return "Breadcrumb Task";
	}

	/**
	 * 
	 */
	public function init( Config $config )
	{
	}

	/**
	 * ٥Ȥ
	 */
	public function processEvent( IEvent $event, ProcedureContext $context )
	{
		// BreadcrumListݡͥȤ
		$breadcrumb = $context->getComponent( "charcoal:BreadcrumbList" );

		// ѥ󤯤ꥹȤ
		$breadcrumb_list = $breadcrumb->makeList( array( 'home', 'sample', 'breadcrumb' ) );

		// LinkerݡͥȤ
		$linker = $context->getComponent( "charcoal:Linker" );

		// ǡ
		$links = $linker->getLinks();

		// HTML
		print '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">' . PHP_EOL;
		print '<HTML>' . PHP_EOL;
		print '<HEAD>' . PHP_EOL;
		print '<META http-equiv="Content-Type" content="text/html; charset=EUC-JP">' . PHP_EOL;
		print '</HEAD>' . PHP_EOL;
		print '<BODY>' . PHP_EOL;

		print $breadcrumb_list . PHP_EOL;	// <== ѥ󤯤ꥹȤν
		print '<p>';

		// ʲLinkerݡͥȤǡ
		print '<table>' . PHP_EOL;
		print '<tr><th>̾</th><th>URL</th></tr>' . PHP_EOL;

		print '<tr>' . PHP_EOL;
		print '  <td>Hello World</td>' . PHP_EOL;
		print '  <td><a href="' . $links['hello_world'] . '">' . $links['hello_world'] . '</a></td>' . PHP_EOL;
		print '</tr>' . PHP_EOL;
		print '<tr>' . PHP_EOL;
		print '  <td>Breadcrumb List</td>' . PHP_EOL;
		print '  <td><a href="' . $links['breadcrumb'] . '">' . $links['breadcrumb'] . '</a></td>' . PHP_EOL;
		print '</tr>' . PHP_EOL;
		print '</table>' . PHP_EOL;

		print '</BODY>' . PHP_EOL;
		print '</HTML>' . PHP_EOL;
	}

}

==> charcoal-0.7.0.zip: charcoal-0.7.0/web_app/02_breadcrumb/classes/tasks/BreadcrumbTask.class.php <==
<?php
/**
* ѥꥹȥ
*
* PHP version 5
*
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/
class BreadcrumbTask extends Object implements ITask
{
	/*
	 *    󥹥ȥ饯
	 */
	public function __construct()
	{
		parent::__construct();
	}

	/**
	 * ̾
	 */
	public function getTaskName()
	{
		return "Breadcrumb Task";
	}

	/**
	 * 
	 */
	public function init( Config $config )
	{
	}

	/**
	 * ٥Ȥ
	 */
	public function processEvent( IEvent $event, ProcedureContext $context )
	{
		// BreadcrumListݡͥȤ
		$breadcrumb = $context->getComponent( s('charcoal:BreadcrumbList') );

		// ѥ󤯤ꥹȤ
		$breadcrumb_list = $breadcrumb->makeList( array( 'home', 'sample', 'breadcrumb' ) );

		// LinkerݡͥȤ
		$linker = $context->getComponent( s('charcoal:Linker') );

		// ǡ
		$links = $linker->getLinks();

		// HTML
		print '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">' . PHP_EOL;
		print '<HTML>' . PHP_EOL;
		print '<HEAD>' . PHP_EOL;
		print '<META http-equiv="Content-Type" content="text/html; charset=EUC-JP">' . PHP_EOL;
		print '</HEAD>' . PHP_EOL;
		print '<BODY>' . PHP_EOL;

		print $breadcrumb_list . PHP_EOL;	// <== ѥ󤯤ꥹȤν
		print '<p>';

		// ʲLinkerݡͥȤǡ
		print '<table>' . PHP_EOL;
		print '<tr><th>̾</th><th>URL</th></tr>' . PHP_EOL;

		print '<tr>' . PHP_EOL;
		print '  <td>Hello World</td>' . PHP_EOL;
		print '  <td><a href="' . $links['hello_world'] . '">' . $links['hello_world'] . '</a></td>' . PHP_EOL;
		print '</tr>' . PHP_EOL;
		print '<tr>' . PHP_EOL;
		print '  <td>Breadcrumb List</td>' . PHP_EOL;
		print '  <td><a href="' . $links['breadcrumb'] . '">' . $links['breadcrumb'] . '</a></td>' . PHP_EOL;
		print '</tr>' . PHP_EOL;
		print '</table>' . PHP_EOL;

		print '</BODY>' . PHP_EOL;
		print '</HTML>' . PHP_EOL;
	}

}
